@@ -1,6 +1,7 @@
 from pathlib import Path
 import sqlite_utils
 import csv
+import pkg_resources
 
 class Quarto:
 
@@ -359,6 +360,7 @@ class Table(View):
                 hugo_file.write(f"title: \"{self._title}\"\n")
                 hugo_file.write("listing:\n")
                 hugo_file.write("  type: table\n")
+                hugo_file.write("  table-striped: true\n")
                 # TODO this should be coming from config
                 hugo_file.write("  field-display-names:\n")
                 for col in self._output_list:
@@ -1228,6 +1230,26 @@ svg.leaflet-image-layer.leaflet-interactive path {
             with open(f"{dir_base}/content/mysite/leaflet.css", "w") as resource_file:
                 resource_file.write(resource_leaflet_css)
 
+
+            leaflet_icon = pkg_resources.resource_stream(__name__, "images/marker-icon.png")
+            leaflet_icon_data = leaflet_icon.read()
+
+            with open(f"{dir_base}/content/mysite/leaflet-icon.png", "wb") as resource_file:
+                resource_file.write(leaflet_icon_data)
+
+
+            leaflet_shadow = pkg_resources.resource_stream(__name__, "images/marker-shadow.png")
+            leaflet_shadow_data = leaflet_shadow.read()
+
+            with open(f"{dir_base}/content/mysite/leaflet-shadow.png", "wb") as resource_file:
+                resource_file.write(leaflet_shadow_data)
+
+            leaflet_icon_2x = pkg_resources.resource_stream(__name__, "images/marker-icon-2x.png")
+            leaflet_icon_2x_data = leaflet_icon_2x.read()
+
+            with open(f"{dir_base}/content/mysite/leaflet-icon-2x.png", "wb") as resource_file:
+                resource_file.write(leaflet_icon_2x_data)
+            
             with open(f"{dir_base}/content/mysite/map/{public_name}/index.qmd", "w") as hugo_file:
                 hugo_file.write("---\n")
                 hugo_file.write(f"title: \"Map\"\n")
